==> ocstore25_6_20.zip: OcStore/Prgm/data/language/en-us/script/CS_peace_town_recycle.lua <==
function E0090()
    MNA()CMU("CS_Vivi")FAI(0)
end
function E0091()
    MNA()CMU("CS_Vivi")FAI(1)
end
function E0092()
    MNA()CMU("CS_Vivi")FAI(2)
end
function E0093()
    MNA()CMU("CS_Vivi")FAI(3)
end
function E0094()
    MNA()CMU("CS_Vivi")FAI(4)
end

function Door_GoPeaceTown()
    PRI()MM0()SOU("CS_011_door")ANP("Door_GoPeaceTown",0,1)FAO(2)TRA("CS_peace_town","E0090",85,34)
end

function Megane1()
    if(FLJ("ExchangeMapSystemAndTranslator")) then
        if(ITJ("MapSystem")) then
            ExchangeMapSystemForTranslator()
        else
            ExchangeTranslatorForMapSystem()
        end
    elseif(FLJ("ChatWithIgor")) then
        KEY()
        FAC("jack_normal")MS3("\nDo you sell any translators?")NOD()CLR()
        FAC()CAT("I do have a second-hand translator.")NOD()
        CAT("\nBut even used ones aren't cheap...")NOD()
        CAT("\nI paid quite a bit for it myself.")NOD()CLR()
        FAC("jack_><")CAT("\nHow much exactly?")NOD()CLR()
        FAC()CAT("\nJust 1000...")NOD()CLR()
        FAC("jack_><")CAT("(Geez, where would we get") 
        CAT("\nthat kind of money...?)")NOD()CLR()
        FAC("jack_normal")CAT("\nCould we possibly rent it for a day?")NOD()CLR()
        FAC()CAT("That works too,")NOD()
        CAT("\nbut you'll need to trade something valuable.")NOD()CLR()
        GIT("MapSystem")
        CAT("\nLike this - MAP SYSTEM -")NOD()CLR()
        GIT()
        CAT("Of course,")NOD()
        CAT("\nwhen you no longer need the translator,")NOD()
        CAT("\nyou can come back to me") 
        CAT("\nanytime for an exchange.")NOD()CLR()
        FLP("ExchangeMapSystemAndTranslator")
        MSD("GetTranslator")
        ExchangeMapSystemForTranslator()
    else
        KEY()MS3("\nDo you have anything to trade?")NOD()CLR()
        FAC("jack_normal")CAT("\nNo, we don't...")NOD()
    end
end

function ExchangeTranslatorForMapSystem()
    KEY()
    FAC("jack_normal")MS3("As for the translator,")
    CAT("\nIt might be really useful later,")NOD()
    CAT("\nso let's keep it.")NOD()
    --[[
    KEY()
    GIT("Translator")
    FAC()CLR()MS3("\n要拿- 翻译机 - 换回 - 地图系统 -吗？")YNJ()CLR()
    if(YES()) then
        FAC("jack_normal")CAT("\n是的，我们现在就要。")NOD()CLR()
        ITS("Translator")
        FAC()CAT("\n交出了 - 翻译机 -")NOD()CLR()
        GIT("MapSystem")
        ITP("MapSystem")
        SOU("CS_038_get_item")
        CAT("\n获得了 - 地图系统 - ")NOD()
    else
        GIT()
        FAC("jack_normal")CAT("\n不，现在先不要。")NOD()CLR()
        FAC()CAT("\n等你们用完可以随时找我换回来。")NOD()
    end
    --]]
end

function ExchangeMapSystemForTranslator()
    KEY()
    GIT("MapSystem")
    FAC()CLR()MS3("Would you like to trade")
    CAT("\nthe - MAP SYSTEM - for the - TRANSLATOR -?")YNJ()CLR()
    if(YES()) then
        FAC("jack_normal")CAT("\nYes, we'll do it now.")NOD()CLR()
        ITS("MapSystem")
        FAC()CAT("\nHanded over the - MAP SYSTEM -")NOD()CLR()
        GIT("Translator")
        ITP("Translator")
        SOU("CS_038_get_item")
        CAT("\nObtained the - TRANSLATOR -")NOD()
    else
        GIT()
        FAC("jack_normal")CAT("\nLet us think about it a bit more.")NOD()CLR()
        FAC()CAT("\nThat's fine, just come see me") 
        CAT("\nwhen you need it~")NOD()
    end
end

function Sprinkler1()
    KEY()
    MS4("\nThis is a sprinkler.")NOD()
end

function Robot1()
    KEY()
    MS4("\nThis is a powered-down robot.")NOD()
end

function Motorcycle1()
    KEY()
    MS4("\nThese are the remains of a motorcycle.")NOD()
end

function Motorcycle2()
    KEY()
    MS4("\nThis is an intact motorcycle.")NOD()
end

==> ocstore25_7_4.zip: OcStore/Prgm/data/language/en-us/script/CS_peace_town_recycle.lua <==
function E0090()
    MNA()CMU("CS_Vivi")FAI(0)
end
function E0091()
    MNA()CMU("CS_Vivi")FAI(1)
end
function E0092()
    MNA()CMU("CS_Vivi")FAI(2)
end
function E0093()
    MNA()CMU("CS_Vivi")FAI(3)
end
function E0094()
    MNA()CMU("CS_Vivi")FAI(4)
end

function Door_GoPeaceTown()
    PRI()MM0()SOU("CS_011_door")ANP("Door_GoPeaceTown",0,1)FAO(2)TRA("CS_peace_town","E0090",85,34)
end

function Megane1()
    if(FLJ("BoughtTranslator")) then
        KEY()MS3("\nDo you have anything to trade?")NOD()CLR()
        FAC("jack_normal")CAT("\nNo, we don't...")NOD()
    elseif(FLJ("ExchangeMapSystemAndTranslator")) then
        if(ITJ("MapSystem")) then
            ExchangeMapSystemForTranslator()
        else
            ExchangeTranslatorForMapSystem()
        end
    elseif(FLJ("ChatWithIgor")) then
        KEY()
        FAC("jack_normal")MS3("\nDo you sell any translators?")NOD()CLR()
        FAC()CAT("I do have a second-hand translator.")NOD()
        CAT("\nBut even used ones aren't cheap...")NOD()
        CAT("\nI paid quite a bit for it myself.")NOD()CLR()
        FAC("jack_><")CAT("\nHow much exactly?")NOD()CLR()
        if(DIF() == 0) then
            FAC()CAT("\nJust 200...")NOD()CLR()
            FAC("jack_normal")CAT("\nOk,I bought it!")NOD()CLR()
            FAC()CAT("\nPaid 200 mimiga coins..")NOD()CLR()
            GIT("Translator")
            ITP("Translator")
            SOU("CS_038_get_item")
            CAT("\nObtained the - TRANSLATOR -")NOD()
            MSD("GetTranslator")
            FLP("BoughtTranslator")
        else
            FAC()CAT("\nJust 1000...")NOD()CLR()
            FAC("jack_><")CAT("(Geez, where would we get") 
            CAT("\nthat kind of money...?)")NOD()CLR()
            FAC("jack_normal")CAT("\nCould we possibly rent it for a day?")NOD()CLR()
            FAC()CAT("That works too,")NOD()
            CAT("\nbut you'll need to trade something valuable.")NOD()CLR()
            GIT("MapSystem")
            CAT("\nLike this - MAP SYSTEM -")NOD()CLR()
            GIT()
            CAT("Of course,")NOD()
            CAT("\nwhen you no longer need the translator,")NOD()
            CAT("\nyou can come back to me") 
            CAT("\nanytime for an exchange.")NOD()CLR()
            FLP("ExchangeMapSystemAndTranslator")
            MSD("GetTranslator")
            ExchangeMapSystemForTranslator()
        end
    else
        KEY()MS3("\nDo you have anything to trade?")NOD()CLR()
        FAC("jack_normal")CAT("\nNo, we don't...")NOD()
    end
end

function ExchangeTranslatorForMapSystem()
    KEY()
    FAC("jack_normal")MS3("As for the translator,")
    CAT("\nIt might be really useful later,")NOD()
    CAT("\nso let's keep it.")NOD()
    --[[
    KEY()
    GIT("Translator")
    FAC()CLR()MS3("\n要拿- 翻译机 - 换回 - 地图系统 -吗？")YNJ()CLR()
    if(YES()) then
        FAC("jack_normal")CAT("\n是的，我们现在就要。")NOD()CLR()
        ITS("Translator")
        FAC()CAT("\n交出了 - 翻译机 -")NOD()CLR()
        GIT("MapSystem")
        ITP("MapSystem")
        SOU("CS_038_get_item")
        CAT("\n获得了 - 地图系统 - ")NOD()
    else
        GIT()
        FAC("jack_normal")CAT("\n不，现在先不要。")NOD()CLR()
        FAC()CAT("\n等你们用完可以随时找我换回来。")NOD()
    end
    --]]
end

function ExchangeMapSystemForTranslator()
    KEY()
    GIT("MapSystem")
    FAC()CLR()MS3("Would you like to trade")
    CAT("\nthe - MAP SYSTEM - for the - TRANSLATOR -?")YNJ()CLR()
    if(YES()) then
        FAC("jack_normal")CAT("\nYes, we'll do it now.")NOD()CLR()
        ITS("MapSystem")
        FAC()CAT("\nHanded over the - MAP SYSTEM -")NOD()CLR()
        GIT("Translator")
        ITP("Translator")
        SOU("CS_038_get_item")
        CAT("\nObtained the - TRANSLATOR -")NOD()
    else
        GIT()
        FAC("jack_normal")CAT("\nLet us think about it a bit more.")NOD()CLR()
        FAC()CAT("\nThat's fine, just come see me") 
        CAT("\nwhen you need it~")NOD()
    end
end

function Sprinkler1()
    KEY()
    MS4("\nThis is a sprinkler.")NOD()
end

function Robot1()
    KEY()
    MS4("\nThis is a powered-down robot.")NOD()
end

function Motorcycle1()
    KEY()
    MS4("\nThese are the remains of a motorcycle.")NOD()
end

function Motorcycle2()
    KEY()
    MS4("\nThis is an intact motorcycle.")NOD()
end
